@@ -1,10 +1,9 @@
 #![warn(clippy::all, clippy::pedantic, clippy::nursery)]
 
-//! A cellular automaton simulation library with `WebAssembly` as a target.
+//! A cellular automaton simulation library targeting `WebAssembly`.
 
-mod automaton;
-
-pub use automaton::{ruleset::*, Automaton};
+pub mod automaton_life_like;
+pub mod rules;
 
 #[cfg(feature = "wee_alloc")]
 #[global_allocator]
